==> haskell-text-builder-dev-0.3.3.2-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-Ksnqx4m4utAGhFmK660RIw
key:                  text-builder-dev-0.3.3.2-Ksnqx4m4utAGhFmK660RIw
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  6f762121bf80dcc719983712400b25ce
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-Ksnqx4m4utAGhFmK660RIw
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    deferred-folds-0.9.18.7-2pSu5gDp6KNLjHRF5BBGE3
    isomorphism-class-0.1.1-BFffQPERRr6CdCsAaGIsxc
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-dev-0.3.3.2-195-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-HPkFXJsXSmdHwamjzkwAqo
key:                  text-builder-dev-0.3.3.2-HPkFXJsXSmdHwamjzkwAqo
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  03793872e16fb644a769984cde137381
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-HPkFXJsXSmdHwamjzkwAqo
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    deferred-folds-0.9.18.7-2FRSHppSlJ3BdcdjCBuCmE
    isomorphism-class-0.1.1-FYLIVDZIsPm2gni9eDHbHI
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
